#!/bin/bash

# Keep track of the current directory.
TOP_DIR=$(pwd)


# Global Settings
# ===============

# Configure which package should be download.
if [[ ! $PACKAGE =~ (standard|full) || -z $PACKAGE ]]; then
    PACKAGE="full"
fi

# Configure which action should be taken.
if [[ ! $ACTION =~ (build|upgrade) || -z $ACTION ]]; then
    ACTION="upgrade"
fi

# Configure if source should be keep.
if [[ -z $SOURCE ]]; then
    SOURCE=false
fi

# Configure .make URI.
BASE_URI="http://drupalcode.org/project/drustack.git/blob_plain/refs/heads/7.x-26.x:"
MAKEFILE_URI="$BASE_URI/makes/$PACKAGE.make"


# Global Functions
# ================

function git_push()
{
    while read DATA; do
        PROJECT=`echo $DATA | sed "s/^.*\/\([^\/]*\)\/\.git/\1/g"`
        cd $DATA/../
        git remote set-url --push origin `whoami`@git.drupal.org:project/$PROJECT.git
        git fetch
        git status
        git remote -v
    done
}

function build_package()
{
    drush make \
        --contrib-destination=profiles/drustack \
        --concurrency=8 \
        --no-cache \
        --prepare-install \
        $MAKEFILE_URI .
    rm -rf profiles/drustack/.gitignore
}

function upgrade_package()
{
    chmod a+w sites/*

    rm -rf profiles/drustack
    drush -y make \
        --concurrency=8 \
        --contrib-destination=profiles/drustack \
        --force-complete \
        --no-cache \
        $MAKEFILE_URI .
    rm -rf profiles/drustack/.gitignore

    chmod a-w sites/*
}

function build_source()
{
    chmod a+w sites/*

    drush make \
        --contrib-destination=profiles/drustack \
        --concurrency=8 \
        --working-copy \
        --no-gitinfofile \
        --no-cache \
        --prepare-install \
        $MAKEFILE_URI .
    find $TOP_DIR -type d -name '.git' | git_push

    chmod a-w sites/*
}

function upgrade_source()
{
    rm -rf profiles/drustack
    drush -y make \
        --concurrency=8 \
        --contrib-destination=profiles/drustack \
        --force-complete \
        --no-cache \
        --no-gitinfofile \
        --working-copy \
        $MAKEFILE_URI .
    find $TOP_DIR -type d -name '.git' | git_push
}


# Install Packages
# ================

set -o xtrace

cd $TOP_DIR
if [[ $ACTION == 'build' ]]; then
    if [[ "$SOURCE" == false ]]; then
        build_package
    else
        build_source
    fi
elif [[ $ACTION == 'upgrade' ]]; then
    if [[ "$SOURCE" == false ]]; then
        upgrade_package
    else
        upgrade_source
    fi
fi
